@@ -1,4 +1,4 @@
-import argparse, hashlib, shlex, shutil
+import argparse, hashlib, operator, shlex, shutil
 from pathlib import Path
 from typing import Dict
 
@@ -27,7 +27,7 @@ DEFAULT_PLAYER_ARGS_SUB = ["--speed=1"]
 DEFAULT_PLAYER_ARGS_NO_SUB = ["--speed=1.46"]
 
 
-def gen_usage(action, default_db):
+def fs_actions_usage(action, default_db):
     return f"""lb {action} [database] [optional args]
 
     Control playback:
@@ -209,7 +209,7 @@ def gen_usage(action, default_db):
 def parse_args(action, default_db, default_chromecast=""):
     parser = argparse.ArgumentParser(
         prog="lb " + action,
-        usage=gen_usage(action, default_db),
+        usage=fs_actions_usage(action, default_db),
     )
 
     parser.add_argument(
@@ -469,7 +469,7 @@ def play(args, m: Dict):
     if args.action in [SC.watch, SC.listen]:
         media_path = Path(args.prefix + media_file).resolve()
         if not media_path.exists():
-            if paths.is_mounted(paths, args.shallow_organize):
+            if args.is_mounted:
                 mark_media_deleted(args, media_file)
             return
         media_file = str(media_path)
@@ -657,6 +657,8 @@ def process_playqueue(args, construct_query=construct_fs_query):
     if shutil.which("mpv") and Path(args.watch_later_directory).exists():
         media = mpv_enrich(args, media)
 
+    args.is_mounted = paths.is_mounted(list(map(operator.itemgetter("path"), media)), args.shallow_organize)
+
     try:
         for m in media:
             play(args, m)
