@@ -11,30 +11,33 @@ from xklb.tube_extract import tube_add, tube_update
 from xklb.utils import SC, log
 
 
+def lb_usage():
+    return """xk media library [lb]
+
+    local media subcommands:
+      fsadd [extract, xr]          Create a local media database; Add folders
+      subtitle [sub]               Find subtitles for local media
+      listen [lt]                  Listen to local media
+      watch [wt]                   Watch local media
+      filesystem [fs]              Browse files
+      bigdirs [largefolders]       View folders which take up much room
+      dedupe                       Deduplicate audio files
+
+    online media subcommands:
+      tubeadd [ta, xt]             Create a tube database; Add playlists
+      tubeupdate [tu]              Get new videos from saved playlists
+      tubelist [playlists]         List added playlists
+      tubewatch [tw, entries]      Watch the tube
+      tubelisten [tl]              Listen to the tube
+
+    browser tab subcommands:
+      tabsadd                      Create a tabs database; Add URLs
+      tabs [tabswatch, tb]         Open your tabs for the day
+    """
+
+
 def print_help(parser):
-    print(parser.description)
-    print(
-        """
-local media subcommands:
-  fsadd [extract, xr]                Create a local media database; Add folders
-  subtitle [sub]                     Find subtitles for local media
-  listen [lt]                        Listen to local media
-  watch [wt]                         Watch local media
-  filesystem [fs]                    Browse files
-  bigdirs [largefolders]             View folders which take up much room
-
-online media subcommands:
-  tubeadd [ta]                       Create a tube database; Add playlists
-  tubeupdate [tu]                    Update your saved playlists
-  tubelist [playlist, playlists]     List added playlists
-  tubewatch [tw, tube, entries]      Watch the tube
-  tubelisten [tl]                    Listen to the tube
-
-browser tab subcommands:
-  tabsadd                            Create a tabs database; Add URLs
-  tabs [tabswatch, tb]               Open your tabs for the day
-"""
-    )
+    print(lb_usage())
     print(parser.epilog)
 
 
@@ -61,8 +64,11 @@ def lb(args=None):
     subp_filesystem = subparsers.add_parser(SC.filesystem, aliases=["fs"], add_help=False)
     subp_filesystem.set_defaults(func=filesystem)
 
-    subp_scripts_lf = subparsers.add_parser("bigdirs", aliases=["largefolders", "large_folders"], add_help=False)
-    subp_scripts_lf.set_defaults(func=scripts.large_folders)
+    subp_bigdirs = subparsers.add_parser("bigdirs", aliases=["largefolders", "large_folders"], add_help=False)
+    subp_bigdirs.set_defaults(func=scripts.large_folders)
+
+    subp_dedupe = subparsers.add_parser("dedupe", add_help=False)
+    subp_dedupe.set_defaults(func=scripts.deduplicate_music)
 
     subp_tabsadd = subparsers.add_parser("tabsadd", add_help=False)
     subp_tabsadd.set_defaults(func=tabs_add)
@@ -71,7 +77,7 @@ def lb(args=None):
 
     subp_tubelist = subparsers.add_parser("tubelist", aliases=["playlist", "playlists"], add_help=False)
     subp_tubelist.set_defaults(func=tube_list)
-    subp_tubeadd = subparsers.add_parser("tubeadd", aliases=["ta"], add_help=False)
+    subp_tubeadd = subparsers.add_parser("tubeadd", aliases=["ta", "xt"], add_help=False)
     subp_tubeadd.set_defaults(func=tube_add)
     subp_tubeupdate = subparsers.add_parser("tubeupdate", aliases=["tu"], add_help=False)
     subp_tubeupdate.set_defaults(func=tube_update)
