@@ -1,4 +1,4 @@
-import enum, os, re
+import enum, os, platform, re
 from pathlib import Path
 from tempfile import gettempdir, mkdtemp
 
@@ -7,6 +7,7 @@ from xklb import utils
 FAKE_SUBTITLE = os.path.join(gettempdir(), "sub.srt")  # https://github.com/skorokithakis/catt/issues/393
 CAST_NOW_PLAYING = os.path.join(gettempdir(), "catt_playing")
 DEFAULT_MPV_SOCKET = os.path.join(gettempdir(), "mpv_socket")
+DEFAULT_MPV_WATCH_LATER = os.path.expanduser("~/.config/mpv/watch_later/")
 SUB_TEMP_DIR = mkdtemp()
 
 
@@ -87,3 +88,12 @@ def get_media_files(path, audio=False):
             video_files.append(str(f))
 
     return video_files
+
+
+def is_mounted(paths, mount_point):
+    if platform.system() == "Linux" and any([mount_point in p for p in paths]):
+        p = Path(mount_point)
+        if p.exists() and not p.is_mount():
+            raise Exception(f"mount_point {mount_point} not mounted yet")
+
+    return True
