@@ -413,6 +413,7 @@ def printer(args, query, bindings):
             wr = csv.DictWriter(virtual_csv, fieldnames=args.cols)
             wr.writerows(selected_cols)
 
+            virtual_csv.seek(0)
             for line in virtual_csv.readlines():
                 if args.moved:
                     print(line.strip().replace(args.moved[0], "", 1))
@@ -437,7 +438,7 @@ def printer(args, query, bindings):
             if len(db_resp) > 1:
                 print(f"{len(db_resp)} media" + (f" (limited to {args.limit})" if args.limit else ""))
 
-            duration = sum(map(operator.itemgetter("duration"), db_resp))
+            duration = sum(map(lambda m: m.get("duration") or 0, db_resp))
             duration = human_time(duration)
             if not "a" in args.print:
                 print("Total duration:", duration)
