@@ -1,13 +1,12 @@
 import argparse, operator
 from copy import deepcopy
 
-import humanize
 from tabulate import tabulate
 
 from xklb import db, utils
 from xklb.fs_actions import construct_search_bindings, parse_args, process_playqueue
 from xklb.player import delete_playlists
-from xklb.utils import DEFAULT_PLAY_QUEUE, SC, col_resize, dict_filter_bool, human_time, log
+from xklb.utils import DEFAULT_PLAY_QUEUE, SC, dict_filter_bool, human_time, log
 
 # TODO: add cookiesfrombrowser: ('firefox', ) as a default
 # cookiesfrombrowser: ('vivaldi', ) # should not crash if not installed ?
@@ -20,7 +19,6 @@ default_ydl_opts = {
     "no_check_certificate": True,
     "no_warnings": True,
     "ignore_no_formats_error": True,
-    "ignoreerrors": "only_download",
     "skip_playlist_after_errors": 20,
     "quiet": True,
     "dynamic_mpd": False,
@@ -173,7 +171,7 @@ def printer(args):
         print(tabulate(tbl, tablefmt="fancy_grid", headers="keys", showindex=False))  # type: ignore
 
         print(f"{len(db_resp)} playlists" if len(db_resp) > 1 else "1 playlist")
-        duration = sum(map(operator.itemgetter("duration"), db_resp))
+        duration = sum(map(lambda m: m.get("duration") or 0, db_resp))
         if duration > 0:
             duration = human_time(duration)
             if not "a" in args.print:
